@@ -6,8 +6,12 @@
 #define HAVE_PQEXECPARAMS 1
 #define HAVE_PQESCAPESTRING 1
 #define HAVE_PQESCAPESTRINGCONN 1
+#define HAVE_PQGETCANCEL 1
 #define HAVE_LO_CREATE 1
 #define HAVE_PG_ENCODING_TO_CHAR 1
 #define HAVE_PQSETCLIENTENCODING 1
+#define HAVE_STRUCT_PGNOTIFY_EXTRA 1
+#define HAVE_ST_EXTRA 1
+#define HAVE_ST_NOTIFY_EXTRA 1
 #define HAVE_UNISTD_H 1
 #endif
